@@ -19,7 +19,7 @@ from alchemite_apiclient.model.categorical_column_info import CategoricalColumnI
 from alchemite_apiclient.model.categorical_column_info_all_of import CategoricalColumnInfoAllOf
 from alchemite_apiclient.model.categorical_column_info_stats import CategoricalColumnInfoStats
 from alchemite_apiclient.model.categorical_model_column_info import CategoricalModelColumnInfo
-from alchemite_apiclient.model.categorical_model_column_info_all_of import CategoricalModelColumnInfoAllOf
+from alchemite_apiclient.model.categorical_model_metrics import CategoricalModelMetrics
 from alchemite_apiclient.model.categorical_prediction import CategoricalPrediction
 from alchemite_apiclient.model.categorical_result import CategoricalResult
 from alchemite_apiclient.model.column_group_batch_request import ColumnGroupBatchRequest
@@ -36,7 +36,7 @@ from alchemite_apiclient.model.continuous_column_info import ContinuousColumnInf
 from alchemite_apiclient.model.continuous_column_info_all_of import ContinuousColumnInfoAllOf
 from alchemite_apiclient.model.continuous_column_info_stats import ContinuousColumnInfoStats
 from alchemite_apiclient.model.continuous_model_column_info import ContinuousModelColumnInfo
-from alchemite_apiclient.model.continuous_model_column_info_all_of import ContinuousModelColumnInfoAllOf
+from alchemite_apiclient.model.continuous_model_metrics import ContinuousModelMetrics
 from alchemite_apiclient.model.dr_auto_umap_reduction_type import DRAutoUMAPReductionType
 from alchemite_apiclient.model.dr_cluster_divergence import DRClusterDivergence
 from alchemite_apiclient.model.dr_data_types import DRDataTypes
@@ -87,10 +87,12 @@ from alchemite_apiclient.model.dimensionality_reduction_request import Dimension
 from alchemite_apiclient.model.dimensionality_reduction_response import DimensionalityReductionResponse
 from alchemite_apiclient.model.empty_categorical_column import EmptyCategoricalColumn
 from alchemite_apiclient.model.empty_continuous_column import EmptyContinuousColumn
+from alchemite_apiclient.model.empty_ordinal_column import EmptyOrdinalColumn
 from alchemite_apiclient.model.error import Error
 from alchemite_apiclient.model.extension import Extension
 from alchemite_apiclient.model.extension_infocol import ExtensionInfocol
 from alchemite_apiclient.model.extension_infocol_arguments import ExtensionInfocolArguments
+from alchemite_apiclient.model.extension_oligo import ExtensionOligo
 from alchemite_apiclient.model.favourite_dataset import FavouriteDataset
 from alchemite_apiclient.model.favourite_job import FavouriteJob
 from alchemite_apiclient.model.favourite_patch import FavouritePatch
@@ -142,6 +144,7 @@ from alchemite_apiclient.model.historic_target_function import HistoricTargetFun
 from alchemite_apiclient.model.historic_value import HistoricValue
 from alchemite_apiclient.model.historic_vector_prediction import HistoricVectorPrediction
 from alchemite_apiclient.model.historic_vector_value import HistoricVectorValue
+from alchemite_apiclient.model.hyperopt_target_function import HyperoptTargetFunction
 from alchemite_apiclient.model.importance_request import ImportanceRequest
 from alchemite_apiclient.model.impute_request import ImputeRequest
 from alchemite_apiclient.model.inline_object import InlineObject
@@ -211,9 +214,11 @@ from alchemite_apiclient.model.new_columns import NewColumns
 from alchemite_apiclient.model.non_empty_categorical_column import NonEmptyCategoricalColumn
 from alchemite_apiclient.model.non_empty_continuous_column import NonEmptyContinuousColumn
 from alchemite_apiclient.model.non_empty_integer_categorical_column import NonEmptyIntegerCategoricalColumn
+from alchemite_apiclient.model.non_empty_ordinal_column import NonEmptyOrdinalColumn
 from alchemite_apiclient.model.numerical_filter import NumericalFilter
 from alchemite_apiclient.model.ot_sample_def_categorical import OTSampleDefCategorical
 from alchemite_apiclient.model.ot_sample_def_continuous import OTSampleDefContinuous
+from alchemite_apiclient.model.ot_sample_def_ordinals import OTSampleDefOrdinals
 from alchemite_apiclient.model.ot_sample_definition import OTSampleDefinition
 from alchemite_apiclient.model.ot_set_inputs import OTSetInputs
 from alchemite_apiclient.model.opaque_column_info import OpaqueColumnInfo
@@ -223,6 +228,11 @@ from alchemite_apiclient.model.optimization_job import OptimizationJob
 from alchemite_apiclient.model.optimize_parameters import OptimizeParameters
 from alchemite_apiclient.model.optimize_request import OptimizeRequest
 from alchemite_apiclient.model.optimize_request_all_of import OptimizeRequestAllOf
+from alchemite_apiclient.model.ordinal_column import OrdinalColumn
+from alchemite_apiclient.model.ordinal_column_info import OrdinalColumnInfo
+from alchemite_apiclient.model.ordinal_column_info_all_of import OrdinalColumnInfoAllOf
+from alchemite_apiclient.model.ordinal_column_info_stats import OrdinalColumnInfoStats
+from alchemite_apiclient.model.ordinal_model_column_info import OrdinalModelColumnInfo
 from alchemite_apiclient.model.outliers_request import OutliersRequest
 from alchemite_apiclient.model.output_tolerance_request import OutputToleranceRequest
 from alchemite_apiclient.model.output_tolerance_response import OutputToleranceResponse
@@ -272,6 +282,7 @@ from alchemite_apiclient.model.sample_def_continuous import SampleDefContinuous
 from alchemite_apiclient.model.sample_def_continuous_with_start import SampleDefContinuousWithStart
 from alchemite_apiclient.model.sample_def_discrete import SampleDefDiscrete
 from alchemite_apiclient.model.sample_def_integer import SampleDefInteger
+from alchemite_apiclient.model.sample_def_ordinal import SampleDefOrdinal
 from alchemite_apiclient.model.sample_def_set import SampleDefSet
 from alchemite_apiclient.model.sample_def_set_string import SampleDefSetString
 from alchemite_apiclient.model.sample_def_start_prop import SampleDefStartProp
