@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 from io import StringIO
 
@@ -36,7 +34,9 @@ output_impute_file = "adrenergic_imputed.csv"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ############################################################################
@@ -106,9 +106,6 @@ impute_request = client.ImputeRequest(
     return_row_headers=True,
     return_column_headers=True,
 )
-response = api_models.models_id_impute_put(
-    model_id, impute_request=impute_request
-)
+response = api_models.models_id_impute_put(model_id, impute_request=impute_request)
 with open(output_impute_file, "w", encoding="UTF-8") as f:
     f.write(response)
-
