@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import csv
 import time
 from io import StringIO
@@ -38,7 +36,9 @@ impute_input_file = "adrenergic_row.csv"
 api_response = api_default.version_get()
 print("------ API & Python Client Versions ------")
 print(api_response)
-print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print(
+    f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})"
+)
 print("------------------------------------------")
 
 ################################################################################
@@ -91,11 +91,10 @@ impute_request = {
     "return_column_headers": True,
     "data": open(impute_input_file).read(),
 }
-response = api_models.models_id_impute_put(
-    model_id, impute_request=impute_request
-)
+response = api_models.models_id_impute_put(model_id, impute_request=impute_request)
 print(response)
 
+
 # Time how long the imputation takes
 def time_impute():
     ts = []
