@@ -17,9 +17,7 @@ def load_file_as_module(name, location):
 
 
 def pytest_configure(config):
-    config.addinivalue_line(
-        "markers", "invalid_request: test is expected to error"
-    )
+    config.addinivalue_line("markers", "invalid_request: test is expected to error")
 
 
 @pytest.mark.parametrize(
@@ -71,9 +69,7 @@ def pytest_configure(config):
         ),
         pytest.param("output_tolerance", ["steels.csv"], id="output_tolerance"),
         pytest.param("predict_trendline", ["steels.csv"], id="predict_trendline"),
-        pytest.param(
-            "preload", ["adrenergic.csv", "adrenergic_row.csv"], id="preload"
-        ),
+        pytest.param("preload", ["adrenergic.csv", "adrenergic_row.csv"], id="preload"),
         pytest.param("query", ["adrenergic.csv"], id="query"),
         pytest.param(
             "sensitivity",
@@ -119,6 +115,7 @@ def pytest_configure(config):
             "validation_predictions", ["steels.csv"], id="validation_predictions"
         ),
         pytest.param("histogram", ["steels.csv"], id="histogram"),
+        pytest.param("ordinals", ["steels.csv", "steels_impute.csv"], id="ordinals"),
     ],
 )
 def test_example(
@@ -126,9 +123,12 @@ def test_example(
     example_data,
     example_dir,
     set_work_dir,
-    written_credentials,
+    credentials_path,
     set_insecure_transport,
 ):
+    # copy credentials to test working directory
+    shutil.copyfile(credentials_path, os.path.join(set_work_dir, "credentials.json"))
+
     example_file_name = "example_" + example_name + ".py"
     example_data.append(example_file_name)
 
